/*
 * Jednoduche kresleni v Jave.
 * 
 * Jiri Skala, unor 2008
 * 
 */
package simpleDrawing;

import java.awt.*;
import java.awt.event.*;
import java.util.Random;

/**
 * Panel do ktereho budeme kreslit.
 * 
 * @author JSkala
 */
class PanelCanvas extends javax.swing.JPanel {

	/**
	 * Casovac pro animaci.
	 */
	private javax.swing.Timer timer;
	
	/**
	 * Uhel otoceni kulicky podel kruznice.
	 * Hodnota je v radianech.
	 */
	private float angle = 0;
	
	
	
	
	
	/**
	 * Polomer velke kruznice, po ktere bude behat kulicka.
	 */
	private final int circleRadius = 200;
	
	/**
	 * Polomer kulicky, ktera bude behat po kruznici.
	 */
	private final int marbleRadius = 10;
	
	/**
	 * Uhlovy krok kulicky po kruznici.
	 * Hodnota je v radianech. 
	 */
	private final float angleIncrement = 0.1f;
	
	
	
	
	
	/**
	 * Konstruktor.
	 */
	public PanelCanvas() {
		
		// zavolame konstruktor panelu
		super();
		
		// pripravime casovac
		timer = new javax.swing.Timer(100, new TimerActionListener());
	}
	
	/**
	 * Spusti/zastavi animaci.
	 * 
	 * @return Vraci true, pokud je na konci metody animace spustena. Jinak vraci false.
	 */
	public boolean toggleAnimate() {
		
		// zjistime stav casovace
		if (timer.isRunning())
		{
			// zastavime casovac
			timer.stop();
			return false;	// animace je zastavena
		}
		else
		{
			// spustime casovac
			timer.start();
			return true;	// animace bezi
		}
	}
	
	/**
	 * Metoda ktera se vyvola pri kresleni panelu.
	 * Nevolat primo, pouzivat repaint().
	 * 
	 * @param g Objekt pro kresleni.
	 */
	public void paint(Graphics g) {
	
		// pretypujeme Graphics na namaklejsi Graphics2D
		Graphics2D gr = (Graphics2D)g;
		
		// zjistime velikost panelu
		int w = this.getWidth();
		int h = this.getHeight();
		
		// nastavime barvu pro kresleni (obrys i vypln)
		gr.setColor(Color.black);
		// nastavime barvu pozadi
		gr.setBackground(Color.white);
		
		// smazeme obsah panelu
		gr.clearRect(0, 0, w, h);
		
		// spocitame souradnice stredu kruznice
		int cx = w / 2;
		int cy = h / 2;
		
		
		// pripravime pole s definici prerusovane cary
		float[] dash = new float[] {30, 10, 5, 10};
		// 30 pixelu cara, 10 mezera, 5 cara, 10 mezera a pak znovu dokola
		
		// pripravime nastaveni kresleni car
		BasicStroke bs = new BasicStroke(
				3,		// tloustka cary
				BasicStroke.CAP_BUTT,	// zakonceni car
				BasicStroke.JOIN_BEVEL,	// spojeni car
				10,		// limit pro spojeni car
				dash,	// prerusovana cara
				0);		// kterym indexem zacit v poli dash
		
		// nastavime styl cary
		gr.setStroke(bs);
		
		
		// nakreslime kruznici
		gr.drawOval(cx-circleRadius, cy-circleRadius, 2*circleRadius, 2*circleRadius);
		
		// spocitame souradnice stredu kulicky
		int mx = (int)(cx + circleRadius * Math.sin(angle));
		int my = (int)(cy - circleRadius * Math.cos(angle));
		
		// nastavime novou barvu pro kresleni
		gr.setColor(Color.blue);
		// nakreslime kulicku
		gr.fillOval(mx-marbleRadius, my-marbleRadius, 2*marbleRadius, 2*marbleRadius);
	}
	
	
	
	
	
	/**
	 * Trida pro obsluhu udalosti casovace.
	 * 
	 * @author Jiri Skala
	 */
	private class TimerActionListener implements ActionListener {
		
		/**
		 * Reakce na tiknuti casovace.
		 * 
		 * @param e Informace o udalosti.
		 */
		public void actionPerformed(ActionEvent e) {
			
			// pootocime kulicku podel kruznice
			angle += angleIncrement;
			
			// pohlidame uhel v intervalu <0, 2pi)
			if (angle >= 2*Math.PI)
				angle -= 2*Math.PI;
			
			// prekreslime obrazek
			repaint();
		}
	}
}
