/*
 * Jednoduche kresleni v Jave.
 * 
 * Jiri Skala, unor 2008
 * 
 */
package simpleDrawing;

import java.awt.*;
import java.awt.event.*;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;

/**
 * Jednoduche kresleni v Jave.
 * 
 * @author Jiri Skala
 */
public class SimpleDrawing extends JFrame {

	/**
	 * Panely pro usporadani ovladacich prvku v okne.
	 */
	private JPanel contentPane, panelTools;
	
	/**
	 * Panel kam budeme kreslit.
	 */
	private PanelCanvas panelCanvas;
	
	/**
	 * Tlacitko pro spusteni/zastaveni animace.
	 */
	private JButton buttonAnimate;
	
	
	
	
	
	/**
	 * Popis tlacitka pro spusteni animace.
	 */
	private final String textRunAnim = "Spust animaci";
	
	/**
	 * Popis tlacitka pro zastaveni animace.
	 */
	private final String textStopAnim = "Zastav animaci";
	
	
	
	
	
	/**
	 * Zobrazi okno aplikace.
	 * 
	 * @param args Command line arguments.
	 */
	public static void main(String[] args) {
		new SimpleDrawing().setVisible(true);
	}

	/**
	 * Konstruktor hlavniho okna.
	 */
	public SimpleDrawing() {
		
		// nastavime vlastnosti okna
		this.setTitle("Jednoduche kresleni");
		this.setSize(800, 600);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		// poskladame GUI
		contentPane = new JPanel(new BorderLayout());
		this.setContentPane(contentPane);
		
		panelTools = new JPanel();
		panelTools.setPreferredSize(new Dimension(200, 200));
		
		panelCanvas = new PanelCanvas();
		
		buttonAnimate = new JButton(textRunAnim);
		buttonAnimate.addActionListener(new buttonActionListener());
		panelTools.add(buttonAnimate);
		
		contentPane.add(panelTools, BorderLayout.WEST);
		contentPane.add(panelCanvas, BorderLayout.CENTER);
	}
	
	
	
	
	
	/**
	 * Trida pro obsluhu udalosti tlacitka.
	 * 
	 * @author Jiri Skala
	 */
	private class buttonActionListener implements ActionListener {
	
		/**
		 * Reakce na stisknuti tlacitka.
		 * 
		 * @param e Informace o udalosti.
		 */
		public void actionPerformed(ActionEvent e) {
			
			// spustime/zastavime animaci
			if (panelCanvas.toggleAnimate())
				// animace bezi
				buttonAnimate.setText(textStopAnim);
			else
				// animace je zastavena
				buttonAnimate.setText(textRunAnim);
		}
	}
}
